#include "core.hpp"
#include <giomm/icon.h>
#include <gtkmm/image.h>
#include <gtkmm/label.h>

namespace core {
    
    db::video getVideoByYTID(std::string yt_id)
    {
        db::video output;

        // 1. Проверить есть ли видео в базе данных
        if (db::getVideoByYTID(yt_id, &output)) {
            // Видео в базе данных найдено
            std::cout << "Видео найдено в базе данных!" << std::endl;
            return output;
        }

        // Видео в базе данных нет. Получаем информацию о нём через ytapi
        ytapi::video_result found_video = ytapi::getVideoByYTID(yt_id);
        output.yt_id        = yt_id;
        output.title        = found_video.title;
        output.description  = found_video.description;
        output.published_at = found_video.published_at;

        // Ищем автора в базе данных
        db::author video_author;
        if (!db::getAuthorByYTID(found_video.author_yt_id, &video_author)) {
            // Автора в базе данных нет. Добавляем
            video_author.yt_id = found_video.author_yt_id;
            video_author.name = found_video.author_name;
            db::addAuthor(&video_author);
        }
        output.author_obj = video_author;

        // Добавляем видео в БД
        db::addVideo(&output);

        return output;
    }

    Gtk::Box* getButtonContents(Glib::ustring text, std::string icon_name)
    {
        // Создание иконки и текста
        auto icon = Gio::Icon::create(icon_name);
        auto img_icon = Gtk::make_managed<Gtk::Image>(icon);
        auto lbl_main = Gtk::make_managed<Gtk::Label>(text);
        lbl_main->set_hexpand(false);

        // Добавление в контейнер
        auto box_main = Gtk::make_managed<Gtk::Box>(
            Gtk::Orientation::HORIZONTAL,
            5);
        box_main->append(*img_icon);
        box_main->append(*lbl_main);

        return box_main;
    }
}